package com.bpcl.lpg.core.service.impl;

import org.slf4j.LoggerFactory;
import org.apache.commons.lang3.StringUtils;
import de.hybris.platform.commerceservices.security.SecureToken;
import java.util.Date;
import de.hybris.platform.commerceservices.security.SecureTokenService;
import org.slf4j.Logger;
import com.bpcl.lpg.core.service.TokenGenerationService;

public class TokenGenerationServiceImpl implements TokenGenerationService
{
    private static final Logger LOG;
    private SecureTokenService secureTokenService;
    private long tokenValiditySeconds;
    
    public String createToken(final String userId) {
        final long timeStamp = (this.getTokenValiditySeconds() > 0L) ? new Date().getTime() : 0L;
        final SecureToken data = new SecureToken(userId, timeStamp);
        return this.getSecureTokenService().encryptData(data);
    }
    
    public boolean validateToken(final String token, final String userId) {
        try {
            final SecureToken data = this.getSecureTokenService().decryptData(token);
            if (this.getTokenValiditySeconds() > 0L) {
                final long delta = new Date().getTime() - data.getTimeStamp();
                return delta / 1000L <= this.getTokenValiditySeconds() && data.getData().equals(userId);
            }
        }
        catch (final Exception exception) {
            TokenGenerationServiceImpl.LOG.error("Exception while validating token", exception.getCause());
        }
        return false;
    }
    
    public String getCustomerIdFromToken(final String token) {
        if (StringUtils.isNotBlank(token)) {
            try {
                final SecureToken data = this.getSecureTokenService().decryptData(token);
                return data.getData();
            }
            catch (final Exception ex) {
                return "";
            }
        }
        TokenGenerationServiceImpl.LOG.error("Token is empty.");
        return "";
    }
    
    public SecureTokenService getSecureTokenService() {
        return this.secureTokenService;
    }
    
    public void setSecureTokenService(final SecureTokenService secureTokenService) {
        this.secureTokenService = secureTokenService;
    }
    
    public long getTokenValiditySeconds() {
        return this.tokenValiditySeconds;
    }
    
    public void setTokenValiditySeconds(final long tokenValiditySeconds) {
        this.tokenValiditySeconds = tokenValiditySeconds;
    }
    
    static {
        LOG = LoggerFactory.getLogger(TokenGenerationServiceImpl.class);
    }
}
